@@ -11,7 +11,7 @@ getDataTypeByNiftiCode <- function (code)
 hasNiftiMagicString <- function (fileName)
 {
     connection <- gzfile(fileName, "rb")
-    seek(connection, where=344)
+    readBin(connection, "raw", n=344)
     magicString <- readBin(connection, "raw", n=4)
     close(connection)
     
@@ -75,41 +75,41 @@ readNifti <- function (fileNames)
 
     if (niftiVersion == 1)
     {
-        seek(connection, where=40)
+        readBin(connection, "raw", n=36)
         dims <- readBin(connection, "integer", n=8, size=2, endian=endian)
-        seek(connection, where=70)
+        readBin(connection, "raw", n=14)
         typeCode <- readBin(connection, "integer", n=1, size=2, endian=endian)
-        seek(connection, where=76)
+        readBin(connection, "raw", n=4)
         voxelDims <- readBin(connection, "double", n=8, size=4, endian=endian)
         dataOffset <- readBin(connection, "double", n=1, size=4, endian=endian)
         slopeAndIntercept <- readBin(connection, "double", n=2, size=4, endian=endian)
-        seek(connection, where=123)
+        readBin(connection, "raw", n=3)
         unitCode <- readBin(connection, "integer", n=1, size=1, endian=endian)
-        seek(connection, where=252)
+        readBin(connection, "raw", n=128)
         qformCode <- readBin(connection, "integer", n=1, size=2, endian=endian)
         sformCode <- readBin(connection, "integer", n=1, size=2, endian=endian)
         quaternionParams <- readBin(connection, "double", n=6, size=4, endian=endian)
         affine <- matrix(readBin(connection, "double", n=12, size=4, endian=endian), nrow=3, byrow=TRUE)
-        seek(connection, where=344)
+        readBin(connection, "raw", n=16)
         magicString <- readBin(connection, "raw", n=4)
     }
     else
     {
         magicString <- readBin(connection, "raw", n=4)
-        seek(connection, where=12)
+        readBin(connection, "raw", n=4)
         typeCode <- readBin(connection, "integer", n=1, size=2, endian=endian)
-        seek(connection, where=16)
+        readBin(connection, "raw", n=2)
         dims <- readBin(connection, "integer", n=8, size=8, endian=endian)
-        seek(connection, where=104)
+        readBin(connection, "raw", n=24)
         voxelDims <- readBin(connection, "double", n=8, size=8, endian=endian)
         dataOffset <- readBin(connection, "integer", n=1, size=8, endian=endian)
         slopeAndIntercept <- readBin(connection, "double", n=2, size=8, endian=endian)
-        seek(connection, where=344)
+        readBin(connection, "raw", n=152)
         qformCode <- readBin(connection, "integer", n=1, size=4, endian=endian)
         sformCode <- readBin(connection, "integer", n=1, size=4, endian=endian)
         quaternionParams <- readBin(connection, "double", n=6, size=8, endian=endian)
         affine <- matrix(readBin(connection, "double", n=12, size=8, endian=endian), nrow=3, byrow=TRUE)
-        seek(connection, where=500)
+        readBin(connection, "raw", n=4)
         unitCode <- readBin(connection, "integer", n=1, size=4, endian=endian)
     }
     
